/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest;


import com.hamburgsud.aludratest.action.interaction.Interaction;
import com.hamburgsud.aludratest.action.verification.Verification;
import com.hamburgsud.log4testing.core.data.TestStepGroup;

/**
 * <code>AludraTest</code> provides access to the application under test for
 * interactions and verifications.
 * 
 * @author <a href="mailto:marcel.malitz@ham.hamburgsud.com">Marcel Malitz</a>
 * 
 */
public interface AludraTest {

	/**
	 * Provides methods to verify some things in the active screen of the
	 * application under test.
	 * 
	 * @return a instance for verifications in the active screen of the
	 *         application under test
	 */
	public Verification verify();

	/**
	 * Provides methods to interact with the active screen of the application
	 * under test.
	 * 
	 * @return a instance for interactions with the active screen of the
	 *         application under test
	 */
	public Interaction perform();

	//TODO diese Methode muss noch in irgendein anderes Interface
	/**
	 * Creates a new {@link TestStepGroup} and returns it. Each command which
	 * will be called after a call of this method will belong to the new created
	 * group. This method is just for logging purposes and helps to structure
	 * test steps in the resulting log files.
	 * 
	 * @param name
	 *            of the new {@link TestStepGroup}
	 * @return the new created {@link TestStepGroup}
	 */
	public TestStepGroup newTestStepGroup(final String name);

}
