/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.action;

import com.hamburgsud.aludratest.caller.CommandCaller;
import com.hamburgsud.aludratest.caller.DefaultCommandCaller;
import com.hamburgsud.aludratest.handler.DefaultExceptionHandler;
import com.hamburgsud.aludratest.handler.ExceptionHandler;
import com.hamburgsud.aludratest.locator.Locator;
import com.hamburgsud.aludratest.wrapper.Wrapper;
import com.hamburgsud.log4testing.core.data.TestCase;

abstract public class Action {

	final private static String TEXT_SEPERATOR = "; ";

	protected Wrapper wrapper;
	protected TestCase testCase;
	protected CommandCaller caller;
	protected ExceptionHandler exceptionHandler;

	private Action() {
		super();
	}

	/**
	 * Checks if the member <code>exceptionHandler</code> is not
	 * <code>null</code> and returns this instance then. If
	 * <code>exceptionHandler</code> is <code>null</code>, it initialises this
	 * instance with {@link DefaultExceptionHandler} and returns it then.<br/>
	 * If you would like to register another exception handler on instantiation
	 * of this class, override this method and return another exception handler.
	 * 
	 * @return the already initialised instance <code>exceptionHandler</code> or
	 *         a new instance of {@link DefaultExceptionHandler}
	 */
	public ExceptionHandler getExceptionHandler() {
		if (exceptionHandler == null) {
			exceptionHandler = new DefaultExceptionHandler();
		}
		return exceptionHandler;
	}

	public Action(final Wrapper wrapper, final TestCase testCase) {
		this();
		this.wrapper = wrapper;
		this.testCase = testCase;
		caller = new DefaultCommandCaller(testCase, getExceptionHandler(),
				wrapper);
	}

	protected String getSeperatedString(final String left, final String right) {
		return left + TEXT_SEPERATOR + right + TEXT_SEPERATOR;
	}

	private String getMessage(final String prefix, final Object... objects) {
		String comment = prefix;
		if (objects.length > 0) {
			comment += objects[0];
		}
		for (int i = 1; i < objects.length; i++) {
			comment = getSeperatedString(comment, objects[i].toString());
		}
		if (objects.length >= 2) {
			comment = comment.substring(0, comment.length() - TEXT_SEPERATOR.length());
		}
		return comment;
	}

	protected String getLocatorMessage(final Locator... locators) {
		return getMessage("USED LOCATORS: ", (Object[]) locators);
	}

	protected String getArgumentMessage(final String... arguments) {
		return getMessage("USED ARGUMENTS: ", (Object[]) arguments);
	}

}
