/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.exception;

import java.util.ArrayList;

import com.hamburgsud.aludratest.locator.Locator;

public class AludraTestException extends Exception {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	public static final String ID_SEPARATOR = ", ";

	private ArrayList<String> locators;

	private String message;

	public AludraTestException() {
	}

	public AludraTestException(final Throwable cause) {
		super(cause);
	}

	public AludraTestException(final Locator locator, final Throwable cause) {
		super(cause);
	}

	public String getMessage() {
		if (message == null) {
			return super.getMessage();
		} else {
			return message;
		}
	}

	protected void setMessage(final String message) {
		this.message = message;
	}

	public ArrayList<String> getLocators() {
		if (locators == null) {
			locators = new ArrayList<String>();
		}
		return locators;
	}

	public void setLocators(final Locator... locators) {
		for (Locator locator : locators) {
			addLocator(locator);
		}
	}

	public void setLocators(final ArrayList<Locator> locators) {
		setLocators(locators.toArray(new Locator[] {}));
	}

	public void addLocator(final Locator locator) {
		locators = new ArrayList<String>();
		locators.add(locator.toString());
	}

	final public String getLocatorsAsString() {
		final StringBuilder locatorStr = new StringBuilder();
		for (final String locator : locators) {
			locatorStr.append(locator).append(ID_SEPARATOR);
		}
		if (locatorStr.length() > 0) {
			locatorStr.delete(locatorStr.length() - ID_SEPARATOR.length(),
					locatorStr.length());
		}
		return locatorStr.toString();
	}

}
