/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.gui.component;


import com.hamburgsud.aludratest.AludraTest;
import com.hamburgsud.log4testing.core.data.TestStep;

public abstract class Element extends GUIComponent {

	public Element(AludraTest aludraTest, Object locator) {
		super(aludraTest, locator);
	}

	public TestStep isEditable() {
		return verify().isEditable(locator);
	}

	public TestStep isPresent() {
		return verify().isElementPresent(locator);
	}

	public TestStep isVisible() {
		return verify().visibility(locator);
	}
	
	public TestStep hasFocus() {
		return verify().hasFocus(locator);
	}
	
	public TestStep focus() {
		return perform().focus(locator);
	}
	
	public TestStep doubleClick() {
		return perform().doubleClick(locator);
	}
	
	public TestStep click() {
		return perform().click(locator);
	}
	
	public TestStep waitForEnabled() {
		return perform().waitForEnabled(locator);
	}
	
	public TestStep waitForInvisible() {
		return perform().waitForInvisible(locator);
	}
	
	public TestStep waitForPresence() {
		String locatorString = locator.toString().replace("\"", "\\\"");
		String script = String.format("selenium.isElementPresent(\"%s\")", locatorString);
		return perform().waitForCondition(script);
	}

}
