/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.gui.component;

import java.util.Set;

import com.hamburgsud.aludratest.AludraTest;
import com.hamburgsud.aludratest.locator.element.XPathLocator;
import com.hamburgsud.log4testing.core.data.TestStep;

public class Table extends Element {

	private static final String XPATH_ROW_COUNT = "//table[contains(@id, \"%s\")]/tbody/tr";

	public Table(AludraTest aludraTest, Object locator) {
		super(aludraTest, locator);
	}
	
	public TestStep rowCount(int expected) {
		String xpath = getRowCountXPath();
		verify().isElementPresent(locator);
		return verify().getXPathCount(xpath, expected);
	}

	private String getRowCountXPath() {
		String xpath;
		if (locator instanceof XPathLocator)
			xpath = locator.toString() + "/tbody/tr";
		else
			xpath = String.format(XPATH_ROW_COUNT, locator);
		return xpath;
	}
	
	public TestStep compareRows(Set<Row> rows) {
		return verify().tableRows(locator, rows);
	}
	
	public int getRowCount() {
		return perform().getXPathCount(getRowCountXPath());
	}
	
	public static class Row {
		private Object[] data;
		private String key;
		private int columns;

		public Row(Object[] data) {
			this.data = data;
			computeKey();
			columns = data.length;
		}

		private void computeKey() {
			StringBuffer b = new StringBuffer();
			for (int i = 0; i < data.length; i++) {
				if (data[i] instanceof Double){
					Double d = (Double) data[i];
					if (d.doubleValue() == d.intValue())
						b.append(d.intValue());
					else
						b.append(d);
				} else {
					b.append(data[i]);
				}
			
			}
			key = b.toString();
		}

		@Override
		public int hashCode() {
			return key.hashCode();
		}

		@Override
		public boolean equals(Object obj) {
			return key.equals(obj.toString());
		}

		@Override
		public String toString() {
			return key;
		}

		public int getColumnCount() {
			return columns;
		}
		
		public boolean isNumber(int c) {
			return data[c] instanceof Number;
		}
	}

}
