/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.junit;


import org.junit.After;
import org.junit.Before;

import com.hamburgsud.aludratest.AludraTest;
import com.hamburgsud.aludratest.DefaultAludraTest;
import com.hamburgsud.aludratest.action.interaction.Interaction;
import com.hamburgsud.aludratest.action.verification.Verification;
import com.hamburgsud.log4testing.core.TestLogger;
import com.hamburgsud.log4testing.core.data.TestCase;
import com.hamburgsud.log4testing.core.data.TestStepGroup;
import com.hamburgsud.log4testing.core.junit.Assert;
import com.hamburgsud.log4testing.core.output.TestLogWriter;

abstract public class AludraTestTestCase implements AludraTest {

	private AludraTest aludraTest;
	protected TestCase testCase;

	abstract public String getTestCaseName();
	
	public AludraTestTestCase() {
		testCase = TestLogger.getTestCase(getTestCaseName());	
	}
	
	@Before
	public void setUp() {
		aludraTest = new DefaultAludraTest(testCase);
	}

	@After
	public void tearDown() {
		perform().tearDown();
		TestLogWriter.write(testCase);
		Assert.assertNotFailed(testCase);
	}

	public Interaction perform() {
		return aludraTest.perform();
	}

	public Verification verify() {
		return aludraTest.verify();
	}

	public TestStepGroup newTestStepGroup(final String name) {
		return aludraTest.newTestStepGroup(name);
	}

}
