/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.locator;

import com.hamburgsud.aludratest.locator.element.ElementLocator;
import com.hamburgsud.aludratest.locator.element.IdLocator;
import com.hamburgsud.aludratest.locator.element.NoElementLocator;
import com.hamburgsud.aludratest.locator.option.LabelLocator;
import com.hamburgsud.aludratest.locator.option.NoOptionLocator;
import com.hamburgsud.aludratest.locator.option.OptionLocator;
import com.hamburgsud.aludratest.locator.window.NoWindowLocator;
import com.hamburgsud.aludratest.locator.window.TitleLocator;
import com.hamburgsud.aludratest.locator.window.WindowLocator;
import com.hamburgsud.aludratest.wrapper.Wrapper;
import com.hamburgsud.aludratest.wrapper.selenium.SeleniumWrapper;

public class LocatorProvider {

	private static ElementLocator getElementLocatorForSelenium(final Object locator) {
		if (locator instanceof String) {
			return new IdLocator((String) locator);
		} else if (locator instanceof ElementLocator) {
			return (ElementLocator) locator; 
		} else {
			return new NoElementLocator(locator);
		}
	}

	public static ElementLocator getDefaultElementLocator(
			final Wrapper wrapper, final Object locator) {
		if (wrapper instanceof SeleniumWrapper) {
			return getElementLocatorForSelenium(locator);
		} else {
			return new NoElementLocator(locator);
		}
	}

	public static ElementLocator[] getDefaultElementLocators(
			final Wrapper wrapper, final Object[] locators) {
		final ElementLocator[] elementLocators = new ElementLocator[locators.length];
		for (int i = 0; i < elementLocators.length; i++) {
			elementLocators[i] = getDefaultElementLocator(wrapper, locators[i]);
		}
		return elementLocators;
	}

	private static OptionLocator getOptionLocatorForSelenium(final Object locator) {
		if (locator instanceof String) {
			return new LabelLocator((String) locator);
		} else if (locator instanceof OptionLocator) {
			return (OptionLocator) locator; 
		} else {
			return new NoOptionLocator(locator);
		}
	}
	
	public static OptionLocator getDefaultOptionLocator(final Wrapper wrapper,
			final Object locator) {
		if (wrapper instanceof SeleniumWrapper) {
			return getOptionLocatorForSelenium(locator);
		} else {
			return new NoOptionLocator(locator);
		}
	}

	public static OptionLocator[] getDefaultOptionLocators(
			final Wrapper wrapper, final Object... locators) {
		final OptionLocator[] optionLocators = new OptionLocator[locators.length];
		for (int i = 0; i < optionLocators.length; i++) {
			optionLocators[i] = getDefaultOptionLocator(wrapper, locators[i]);
		}
		return optionLocators;
	}

	private static WindowLocator getWindowLocatorForSelenium(final Object locator) {
		if (locator instanceof String) {
			return new TitleLocator((String) locator);
		} else if (locator instanceof TitleLocator) {
			return (TitleLocator) locator;
		} else {
			return new NoWindowLocator(locator);
		}
	}
	
	public static WindowLocator getDefaultWindowLocator(final Wrapper wrapper,
			final Object locator) {
		if (wrapper instanceof SeleniumWrapper) {
			return getWindowLocatorForSelenium(locator);
		} else {
			return new NoWindowLocator(locator);
		}
	}

	public static WindowLocator[] getDefaultWindowLocators(
			final Wrapper wrapper, final Object... locators) {
		final WindowLocator[] windowLocators = new WindowLocator[locators.length];
		for (int i = 0; i < windowLocators.length; i++) {
			windowLocators[i] = getDefaultWindowLocator(wrapper, locators[i]);
		}
		return windowLocators;
	}

}
