/**
 * Copyright (C) 2010 Hamburg Sud
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hamburgsud.aludratest.locator.element;

import java.util.Iterator;
import java.util.Vector;

import org.apache.commons.lang.StringUtils;

public class ElementLocators extends ElementLocator implements
		Iterable<ElementLocator> {

	private interface Operation {

		void init();

	}

	private Vector<ElementLocator> elementLocators;
	private ElementLocator pointer;

	public ElementLocators(final String... locators) {
		super(StringUtils.EMPTY);
		init(new Operation() {

			public void init() {
				addAll(locators);
			}

		});
	}

	public ElementLocators(final ElementLocator... locators) {
		super(StringUtils.EMPTY);
		init(new Operation() {

			public void init() {
				addAll(locators);
			}

		});
	}

	private void init(Operation operation) {
		preInit();
		operation.init();
		postInit();
	}

	private void preInit() {
		elementLocators = new Vector<ElementLocator>();
	}

	private void postInit() {
		resetPointer();
	}

	public void addAll(final ElementLocator... locators) {
		for (final ElementLocator locator : locators) {
			add(locator);
		}
	}

	public void addAll(final String... locators) {
		for (String locator : locators) {
			add(new IdLocator(locator));
		}
	}

	public void resetPointer() {
		setPointer(elementLocators.firstElement());
	}

	public void setPointer(final ElementLocator pointer) {
		this.pointer = pointer;
	}

	@Override
	public String toString() {
		return pointer.toString();
	}

	public ElementLocator getPointer() {
		return pointer;
	}

	public Iterator<ElementLocator> iterator() {
		return elementLocators.iterator();
	}

	private boolean add(final ElementLocator locator) {
		return elementLocators.add(locator);
	}

}
